   
library(ggpubr)
library(dplyr)


data <- "~/01_data/"
test <- "~/02_test_analyses/"


setwd(data)

#read in our data

full <- read.csv("Q-fly_S1_individual_data.csv")


###########Calculate FA value, avg AR, relative AR, average wing length & area for each individual#########

full$fluc_asym <- pmax(full$L_area, full$R_area)/pmin(full$L_area, full$R_area)
full$avg_wing_area <- (full$L_area+full$R_area)/2
full$avg_aspect <- (full$L_AR+full$R_AR)/2
full$relative_AR <- full$avg_aspect/full$intertegular_length
full$avg_wing_length <- (full$L_length+full$R_length)/2

males <- full[full$sex == "M",]
females <- full[full$sex == "F",]
full = rbind(males, females)


setwd(test)

################# t-test for intertegular length ############

#get mean and sd
group_by(full, sex) %>%
  summarise(
    count = n(),
    mean = mean(intertegular_length, na.rm = TRUE),
    sd = sd(intertegular_length, na.rm = TRUE)
  )

t.test(intertegular_length ~ sex, data =full, var.equal = TRUE)  ##t = 5.4727, df = 329, p-value = 8.799e-08



################# t-test for AR & relative AR ############


### AR
group_by(full, sex) %>%
  summarise(
    count = n(),
    mean = mean(avg_aspect, na.rm = TRUE),
    sd = sd(avg_aspect, na.rm = TRUE)
  )

t.test(avg_aspect ~ sex, data =full, var.equal = TRUE) ##t = -3.2096, df = 329, p-value = 0.00146


### relative AR
group_by(full, sex) %>%
  summarise(
    count = n(),
    mean = mean(relative_AR, na.rm = TRUE),
    sd = sd(relative_AR, na.rm = TRUE)
  )

t.test(relative_AR ~ sex, data =full, var.equal = TRUE) ##t = -6.1878, df = 329, p-value = 1.812e-09



################# t-test for FA ############

group_by(full, sex) %>%
  summarise(
    count = n(),
    mean = mean(fluc_asym, na.rm = TRUE),
    sd = sd(fluc_asym, na.rm = TRUE)
  )

t.test(FA ~ sex, data =full, var.equal = TRUE) ##t = 0.23349, df = 329, p-value = 0.8155



#make boxplot
p1 <- ggboxplot(full, x = "sex", y = "intertegular_length", 
                color = "sex", palette = c("#00AFBB", "#E7B800"),
                ylab = "Intertegular length (in mm)") + theme(legend.position = "none") +
  theme(axis.title.x = element_blank())

p2 <- ggboxplot(full, x = "sex", y = "avg_aspect", 
                color = "sex", palette = c("#00AFBB", "#E7B800"),
                ylab = "Average wing aspect ratio", xlab = NULL) + theme(legend.position = "none")+
  theme(axis.title.x = element_blank())

p3 <- ggboxplot(full, x = "sex", y = "relative_AR", 
                color = "sex", palette = c("#00AFBB", "#E7B800"),
                ylab = "Relative wing aspect ratio", xlab = NULL) + theme(legend.position = "none")+
  theme(axis.title.x = element_blank())

p4 <-ggboxplot(full, x = "sex", y = "fluc_asym", 
               color = "sex", palette = c("#00AFBB", "#E7B800"),
               ylab = "Fluctuating asymmetry", xlab = NULL) + theme(legend.position = "none")+
  theme(axis.title.x = element_blank())


library(gridExtra)
grid.arrange( p1, p2, p3, p4, nrow = 1)


#########test correlation between intertegular length and wing AR, length and area

ARandSize <- lm(intertegular_length ~ avg_aspect, data = full)
summary(ARandSize) #-0.08644 Std Error = 0.09278 t = -0.932 p = 0.352

WingLengthandSize <- lm(intertegular_length ~ avg_wing_length, data = full)
summary(WingLengthandSize) #0.33154    Std Error = 0.01156  t = 28.675   p < 2e-16
WingAreaandSize <- lm(intertegular_length ~ avg_wing_area, data = full)
summary(WingAreaandSize) #0.105578   Std Error = 0.003943   t = 26.78   p < 2e-16





###### #test bergmannn's rule #########

latitudexsize<- lm(intertegular_length ~ Latitude_abs * sex, data = full)
latitudeplussize <- lm(intertegular_length ~ Latitude_abs + sex, data = full)
anova(latitudexsize, latitudeplussize)

anova(latitudexsize, test = 'Chisq')
anova(latitudeplussize, test = 'Chisq')
 # latitude: Df = 1 F = 19.632 Pr = 1.282e-05; sex: Df = 1 F = 29.884 Pr = 9.097e-08

bergmannsrule <- glm(intertegular_length ~ Latitude_abs, data = full, family = gaussian())
summary(bergmannsrule) #0.005686   Std Error = 0.001338   t = 4.248 Pr = 2.81e-05
confint(bergmannsrule) #0.0031, 0.0083


  
###### test allen's rule on body size #######
  
aridityxsize<- lm(intertegular_length ~ Aridity_annual_mean * sex, data = full)
aridityplussize <- lm(intertegular_length ~ Aridity_annual_mean + sex, data = full)
anova(aridityxsize, aridityplussize)
  
anova(aridityxsize, test = 'Chisq')
anova(aridityplussize, test = 'Chisq')
# aridity: Df = 1 F = 0.140 Pr = 0.7085 sex: Df = 1 F = 29.933 Pr = 8.891e-08



####### StepAIC & glm on intertegular length ########
library(MASS)
intertegular_full_data <- full[,c(3, 2, 16:24)]
intertegular_full <- lm(intertegular_length ~ ., data = intertegular_full_data)
intertegular_full_stepwise <-stepAIC(intertegular_full, direction = "both" )
summary(intertegular_full_stepwise)
intertegular_full_stepwise$anova

#do a glm only with the detected variables

body_size_glm <- intertegular_full_data[,c(1:11)]
fit_body_size <- glm(intertegular_length ~ sex + Temp_ann_mean + Temp_coldest_month_min + 
                       Precip_seasonality, data = body_size_glm, family = gaussian())


summary(fit_body_size)
confint(fit_body_size)
exp(coef(fit_body_size))
residuals(fit_body_size, type = "deviance")





######## test Allen's rule on wing AR ###########


aridityxavgAR<- lm(avg_aspect ~ Aridity_annual_mean * sex, data = full)
aridityplusavgAR <- lm(avg_aspect ~ Aridity_annual_mean + sex, data = full)
anova(aridityxavgAR, aridityplusavgAR)

anova(aridityxavgAR, test = 'Chisq')
anova(aridityplusavgAR, test = 'Chisq')
#aridity: df = 1 F = 2.4071 Pr = 0.1217487; sex: df = 1 F = 12.2094 Pr = 0.0005408



####### StepAIC & glm on AR ########
AR_full_data <- full[,c(27, 2, 16:24)]
AR_full <- lm(avg_aspect ~ ., data = AR_full_data)
AR_full_stepwise <-stepAIC(AR_full, direction = "both" )
summary(AR_full_stepwise)
AR_full_stepwise$anova

#do a glm only with the detected variables

avg_AR_glm <- AR_full_data[,c(1:3, 5)]
fit_avg_AR <- glm(avg_aspect ~ sex+Temp_ann_mean+Temp_month_hottest_max, data = avg_AR_glm, family = gaussian())

summary(fit_avg_AR)
confint(fit_avg_AR)
exp(coef(fit_avg_AR))
residuals(fit_avg_AR, type = "deviance")






###########relative AR#########


######test allen's rule

aridityxrelativeAR<- lm(relative_AR ~ Aridity_annual_mean * sex, data = full)
aridityplusrelativeAR <- lm(relative_AR ~ Aridity_annual_mean + sex, data = full)
anova(aridityxrelativeAR, aridityplusrelativeAR)

anova(aridityxrelativeAR, test = 'Chisq')
anova(aridityplusrelativeAR, test = 'Chisq')
#aridity: df = 1 F = 0.2428  Pr = 0.6225; sex: df = 1 F = 40.2081 Pr = 7.558e-10



####### StepAIC on relative AR
relativeAR_full_data <- full[,c(28, 2, 16:24)]
relativeAR_full <- lm(relative_AR ~ ., data = relativeAR_full_data)
relativeAR_full_stepwise <-stepAIC(relativeAR_full, direction = "both" )
summary(relativeAR_full_stepwise)
relativeAR_full_stepwise$anova

#do a glm only with the detected variables

relative_AR_glm <- relativeAR_full_data[,c(1:2,4,5,7)]
fit_relative_AR <- glm(relative_AR ~ sex + Temp_coldest_month_min + Temp_month_hottest_max + 
                    Precip_seasonality, data = relative_AR_glm, family = gaussian())

summary(fit_relative_AR)
confint(fit_relative_AR)
exp(coef(fit_relative_AR))
residuals(fit_relative_AR, type = "deviance")




############# FA ##########

######test allen's rule

aridityxFA<- lm(fluc_asym ~ Aridity_annual_mean * sex, data = full)
aridityplusFA <- lm(fluc_asym ~ Aridity_annual_mean + sex, data = full)
anova(aridityxFA, aridityplusFA)

anova(aridityxFA, test = 'Chisq')
anova(aridityplusFA, test = 'Chisq')
#aridity: df = 1 F = 1.6834  Pr = 0.1954; sex: df = 1 F = 1.4348 Pr = 0.2319


####### StepAIC on FA
FA_full_data <- full[,c(25, 2, 16:24)]
FA_full <- lm(fluc_asym ~ ., data = FA_full_data)
FA_full_stepwise <-stepAIC(FA_full, direction = "both" )
summary(FA_full_stepwise)
FA_full_stepwise$anova

#do a glm only with the detected variables

FA_glm <- FA_full_data[,c(1,4,6,7,8,10)]
fit_FA <- glm(fluc_asym ~ Temp_coldest_month_min + Aridity_annual_mean + Precip_seasonality + 
                Precipit_wettest_period + Humidity._ann_mean, data = FA_glm, family = gaussian())

summary(fit_FA)
confint(fit_FA)
exp(coef(fit_FA))
residuals(fit_FA, type = "deviance")



#####scatter plot for FA
FAplot1 <- ggscatter(full, y = "fluc_asym", x = "Precipit_wettest_period", 
                     xlab = "Precipitation in the wettest period", ylab = "Fluctuating asymmetry", 
                     size = 1, shape = 1)
FAplot2 <- ggscatter(full, y = "fluc_asym", x = "Temp_coldest_month_min", 
                     xlab = "Minimum temperature in the coldesr month", ylab = "fluctuating asymmetry",
                     size = 1, shape = 1)
FAplot3 <- ggscatter(full, y = "fluc_asym", x = "Aridity_annual_mean", 
                     xlab = "Annual mean aridity", ylab = "fluctuating asymmetry",
                     size = 1, shape = 1)
grid.arrange( FAplot1, FAplot2, FAplot3, nrow = 1)




##############glm for FA less than M+3SD
FA_less_than_3SD <- subset(full, fluc_asym < 1.10)


lowFA_full_data <- FA_less_than_3SD[,c(25, 2, 16:24)]
lowFA_full <- lm(fluc_asym ~ ., data = lowFA_full_data)
lowFA_stepwise <-stepAIC(lowFA_full, direction = "both" )
summary(lowFA_stepwise)
lowFA_stepwise$anova

#do a glm only with the detected variables

lowFA_glm <- lowFA_full_data[,c(1,4,6,7,8)]
fit_lowFA <- glm(fluc_asym ~ Temp_coldest_month_min + Aridity_annual_mean + Precip_seasonality + 
                Precipit_wettest_period, data = lowFA_glm, family = gaussian())

summary(fit_lowFA)
confint(fit_lowFA)
exp(coef(fit_lowFA))
residuals(fit_lowFA, type = "deviance")







